# Lineární vektorové prostory

Příklady:

| zápis      | typ                                         |
| ---------- | ------------------------------------------- |
| $R^2, R^3$ | geometrické vektory o 2, resp. 3 složkách   |
| $R^n$      | n-tice reálných čísel (aritmetické vektory) |
| $M_{m,n}$  | všechny matice typu m/n (nad $R$, nad $C$)  |
| $P_n$      | všechny polynomy stupně nejvýše n           |
| $C(a,b)$   | všechny funkce spojité na $<a, b>$          |

Vektorový prostor V nad tělesem K:
- sčítání: $V + V \to V$
- násobení: $K \cdot V \to V$

## Lineární vektorový prostor

**Lineární vektorový prostor nad tělesem $\mathbb T$** (nad $\mathbb{C}$ nebo $\mathbb{R}$) je neprázdná množina $\mathcal{V}$, kde pro každé $\vec x, \vec y, \vec z \in \mathcal{V}$ a pro každé $k, l \in \mathbb T$ platí:

| vlastnost                                                                                       | název           |
| ----------------------------------------------------------------------------------------------- | --------------- |
| existuje právě jeden prvek $\vec u \in \mathcal{V}$ tak, že $\vec u = \vec x + \vec y$          | sčítání         |
| existuje právě jeden prvek $\vec u \in \mathcal{V}$ tak, že $\vec u = k \vec x$                 | násobení        |
| $(\vec x + \vec y) + \vec z = \vec x + (\vec y + \vec z)$                                       |                 |
| existuje prvek $\vec o \in \mathcal{V}$ takový, že $\vec x + \vec o = \vec o + \vec x = \vec x$ | neutrální prvek |
| existuje prvek $-\vec{x}$ takový, že $\vec{x} + (-\vec{x}) = -\vec{x} + \vec{x} = \vec{o}$      | opačný prvek    |
| $(k+l)\vec x = k\vec x + l\vec x$                                                               |                 |
| $(kl)\vec x = k(l\vec x)$                                                                       |                 |
| $1\vec x = \vec x$                                                                              |                 |
| $k(\vec x + \vec y) = k\vec x + k\vec y$                                                        |                 |

### Základní vlastnosti LVP

- nulový prvek je určen jednoznačně
- je-li $\vec{x}+\vec{y}=\vec{x}+\vec{z}$, pak $\vec{y}=\vec{z}$
- pro všechna $\vec{x} \in \mathcal{V}$ je opačný prvek $-\vec{x}$ určen jednoznačně
- je-li $\vec{x}+\vec{y}=\vec{z}$, pak $\vec{x}=\vec{z}+(-\vec{y})$
- pro všechna $\vec{x} \in \mathcal{V}$ a $k \in \mathbb{R}$ je $0\vec{x}=k\vec{o}=\vec{o}$
- pro všechna $\vec{x} \in \mathcal{V}$ je $-1\vec{x}=-\vec{x}$
- je-li $k\vec{x}=\vec{o}$, pak buď $k=0$ nebo $\vec{x}=\vec{o}$

### Podprostor

Máme lineární vektorový prostor $V$ a jeho podprostor $U \subset V$, jestliže
1) pro každé $\vec{u}, \vec{v} \in U$ je $\vec{u} + \vec{v} \in U$
2) pro každé $\vec{u} \in U$ a pro každé $a \in K$ je $a \cdot \vec{u} \in U$
	- vyplývá, že v podprostoru $U$ bude vždy i nulový vektor ($a = 0$)

Každý podprostor vektorového prostoru je také vektorovým prostorem.

### Lineární kombinace

Prvek $\lambda_{1} \vec v_{1} + \lambda_{2} \vec v_{2} + \dots + \lambda_{k} \vec v_{k}$ (**LK**), kde $\vec v_{i}$ jsou prvky LVP $\mathcal{V}$ a $\lambda_{i}$ jsou koeficienty.

#### Lineární (ne)závislost

Prvky nazveme **lineárně nezávislými** (**LN**), jestliže se žádný z nich nedá vyjádřit lineární kombinací ostatních prvků (neboli $LK = \vec{o}$, jedině když $\lambda=0$). V opačném případě budou prvky **lineárně závislé** (**LZ**).

#### Lineární obal

Všechny lineární kombinace zadaných vektorů.
- zapisujeme $\langle\vec{u}; \vec{v}\rangle = \{ \lambda_{1} \cdot \vec{u} + \lambda_{2} \cdot \vec{v} \}$

### Generující množina

Množina $M = \{\vec{v_{1}}, \vec{v_{2}}, \dots, \vec{v_{k}}\} \subseteq V$ generuje lineární vektorový prostor, jestliže se lineární kombinace všech prvků M rovná prostoru V, tedy $\langle M \rangle = V$. 

### Báze

Je-li generující množina prostoru V lineárně nezávislá, jedná se také o bázi prostoru V.
- zápis: $\text{báze }A = \{\vec{v_{1}}, \vec{v_{2}}\}$

Bázi z generující množiny zjistím tím, že vektory GM zapíšu **do sloupců** matice a provedu **GJEM**, čímž zjistím, jestli se nedá některý z vektorů **vyjádřit jako LK jiného vektoru** (tedy vyjde jako **parametr**).

#### Dimenze V

Počet prvků báze V se nazývá **dimenze V** a značí se $dim(V)$.

Dimenzi vypočítám **zjištěním báze**, kde **počet prvků báze** je roven **dimenzi V**.

#### Souřadnice v bázi

Jednoznačně určené koeficienty $c_{1}, c_{2}, \dots, c_{n} \in \mathbb{R}$ LK $v = c_{1}\vec{b_{1}}, c_{2}\vec{b_{2}}, \dots, c_{n}\vec{b_{n}}$ se nazývají **souřadnice prvku v** v bází B.
- značí se $\widehat{v_{B}} = [c_{1}, c_{2}, \dots, c_{n}]^T$

Pořadí prvků v bázi je důležité! Při změně pořadí se změní i pořadí souřadnic:

$$B_{1} = \{ \vec{b_{1}}, \vec{b_{2}}, \vec{b_{3}} \} \qquad \vec{x}_{B_{1}} = [1, 2, 3]$$
$$B_{2} = \{ \vec{b_{2}}, \vec{b_{1}}, \vec{b_{3}} \} \qquad \vec{x}_{B_{2}} = [2, 1, 3]$$

Souřadnice součtu dvou prvků V jsou součtem souřadnic těchto prvků. 

$$\widehat{(\vec{v_{1}} + \vec{v_{2}})}_{B} = \widehat{\vec{v_{1}}_{B}} + \widehat{\vec{v_{2}}_{B}}$$
$$\widehat{(\lambda \cdot\vec{v_{2}})}_{B} = \lambda \cdot \widehat{\vec{v_{2}}_{B}}$$

### Určení souřadnic vektoru v bázi

1. Bázové prvky zapíšeme do levé strany matice do sloupců.
2. Vektor zapíšeme do pravé strany matice.
3. Pomocí GJEM převedeme levou stranu matice do tvaru jednotkové matice.
4. Na pravé straně máme souřadnice v zadané bázi.

### Operace s podprostory

- Sjednocení $u_{1} \cup u_{2}$
	- Musí platit:
		- $u_{1} \subseteq u_{2}$
		- $u_{2} \subseteq u_{1}$